"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeConfig = exports.compileFile = exports.getBuildDestinationPath = exports.isJSFile = exports.getPackgeJSFiles = exports.getPackageFiles = exports.getPackageDirs = void 0;

var _ajv = _interopRequireDefault(require("ajv"));

var babel = _interopRequireWildcard(require("@babel/core"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _fs = _interopRequireDefault(require("fs"));

var _glob = _interopRequireDefault(require("glob"));

var _yargs = _interopRequireDefault(require("yargs"));

var _omit = _interopRequireDefault(require("lodash/omit"));

var _args = _interopRequireDefault(require("../schemas/args"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const validateArgs = new _ajv.default({
  allErrors: true,
  coerceTypes: 'array',
  useDefaults: true
}).compile(_args.default);

const getPackageDirs = async ({
  packagesDir,
  ignoredPackages
}) => (await _fsExtra.default.readdir(packagesDir)).map(file => _path.default.resolve(packagesDir, file)).filter(file => _fs.default.lstatSync(_path.default.resolve(file)).isDirectory()).filter(dir => !ignoredPackages.includes(_path.default.basename(dir)));

exports.getPackageDirs = getPackageDirs;

const getPackageFiles = ({
  pkg,
  srcDir,
  globPattern = '**'
}) => {
  const pkgSrcDir = _path.default.resolve(pkg, srcDir);

  const pattern = _path.default.resolve(pkgSrcDir, globPattern);

  return _glob.default.sync(pattern, {
    nodir: true
  });
};

exports.getPackageFiles = getPackageFiles;

const getPackgeJSFiles = ({
  pkg,
  srcDir
}) => getPackageFiles({
  pkg,
  srcDir,
  globPattern: '**/*.js?(x)'
});

exports.getPackgeJSFiles = getPackgeJSFiles;

const isJSFile = file => ['.js', '.jsx'].includes(_path.default.extname(file));

exports.isJSFile = isJSFile;

const getBuildDestinationPath = ({
  srcPath,
  packagesDir,
  srcDir,
  buildDir
}) => {
  const [pkgName] = _path.default.relative(packagesDir, srcPath).split(_path.default.sep);

  const pkg = _path.default.resolve(packagesDir, pkgName);

  const pkgSrcDir = _path.default.resolve(pkg, srcDir);

  const pkgBuildDir = _path.default.resolve(pkg, buildDir);

  const relativeToSrcPath = _path.default.relative(pkgSrcDir, srcPath);

  return _path.default.resolve(pkgBuildDir, relativeToSrcPath);
};

exports.getBuildDestinationPath = getBuildDestinationPath;

const compileFile = async ({
  file,
  babelConfig,
  packagesDir,
  srcDir,
  buildDir
}) => {
  const destPath = getBuildDestinationPath({
    srcPath: file,
    packagesDir,
    srcDir,
    buildDir
  });

  if (!isJSFile(file)) {
    return _fsExtra.default.copy(file, destPath);
  }

  const transformed = babel.transformFileSync(file, babelConfig).code;
  return _fsExtra.default.outputFile(destPath, transformed);
};

exports.compileFile = compileFile;

const makeConfig = (config = {}) => {
  const finalConfig = _objectSpread({
    packagesDir: _path.default.resolve('./packages'),
    babelConfig: require('../../../../babel.config'),
    // eslint-disable-line global-require
    watchGlob: [_path.default.resolve('./packages/*/src/**')]
  }, (0, _omit.default)(_yargs.default.array('watchGlob').array('ignoredPackages').argv, ['_', '$0']), {}, config);

  try {
    const oorsConfig = require(`${process.cwd()}/oors.config.js`); // eslint-disable-line


    Object.assign(finalConfig, oorsConfig.default || oorsConfig);
  } catch (err) {
    console.log('Unable to locate a oors.config.js file.'); // eslint-disable-line no-console
  }

  if (!validateArgs(finalConfig)) {
    throw new Error(`Invalid args! \n ${JSON.stringify(validateArgs.errors)}`);
  }

  return finalConfig;
};

exports.makeConfig = makeConfig;