#!/usr/bin/env node
"use strict";

var babel = _interopRequireWildcard(require("@babel/core"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _utils = require("../libs/utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

process.on('unhandledRejection', reason => console.log(reason)); // eslint-disable-line

process.on('uncaughtException', err => console.log(err)); // eslint-disable-line

const run = async ({
  packagesDir,
  babelConfig,
  ignoredPackages,
  srcDir,
  buildDir
}) => {
  const packages = await (0, _utils.getPackageDirs)({
    packagesDir,
    ignoredPackages
  });
  return Promise.all(packages.map(async pkg => {
    const pkgSrcDir = _path.default.resolve(pkg, srcDir);

    const pkgBuildDir = _path.default.resolve(pkg, buildDir);

    const files = (0, _utils.getPackageFiles)({
      pkg,
      srcDir
    });
    await _fsExtra.default.ensureDir(pkgBuildDir);
    await _fsExtra.default.emptyDir(pkgBuildDir);
    return Promise.all(files.map(file => {
      const relativeToSrcPath = _path.default.relative(pkgSrcDir, file);

      const destPath = _path.default.resolve(pkgBuildDir, relativeToSrcPath);

      if (!(0, _utils.isJSFile)(file)) {
        return _fsExtra.default.copy(file, destPath);
      }

      const transformed = babel.transformFileSync(file, babelConfig).code;
      return _fsExtra.default.outputFile(destPath, transformed);
    }));
  }));
};

run((0, _utils.makeConfig)());