#!/usr/bin/env node
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.compileFile = exports.getBuildDestinationPath = void 0;

var babel = _interopRequireWildcard(require("@babel/core"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _chokidar = _interopRequireDefault(require("chokidar"));

var _fs = _interopRequireDefault(require("fs"));

var _yargs = _interopRequireDefault(require("yargs"));

var _utils = require("../libs/utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

process.on('unhandledRejection', reason => console.log(reason)); // eslint-disable-line

process.on('uncaughtException', err => console.log(err)); // eslint-disable-line

const getBuildDestinationPath = ({
  file,
  srcDir,
  buildDir
}) => _path.default.resolve(buildDir, _path.default.relative(srcDir, file));

exports.getBuildDestinationPath = getBuildDestinationPath;

const compileFile = async ({
  file,
  srcDir,
  buildDir
}) => {
  const destPath = getBuildDestinationPath({
    file,
    srcDir,
    buildDir
  });

  if (!(0, _utils.isJSFile)(file)) {
    return _fsExtra.default.copy(file, destPath);
  }

  const {
    code
  } = await babel.transformFileAsync(file);
  return _fsExtra.default.outputFile(destPath, code);
};

exports.compileFile = compileFile;

const run = async ({
  srcDir,
  buildDir
}) => {
  const watcher = _chokidar.default.watch(_path.default.join(srcDir, '**'), {
    ignoreInitial: true
  });

  watcher.on('add', file => compileFile({
    file,
    srcDir,
    buildDir
  }));
  watcher.on('change', file => compileFile({
    file,
    srcDir,
    buildDir
  }));
  watcher.on('unlink', file => _fs.default.unlinkSync(getBuildDestinationPath({
    file,
    srcDir,
    buildDir
  })));
  watcher.on('unlinkDir', file => _fsExtra.default.remove(getBuildDestinationPath({
    file,
    srcDir,
    buildDir
  })));
  return watcher;
};

const {
  argv
} = _yargs.default;
run({
  srcDir: argv.src || 'src',
  buildDir: argv.build || 'build'
});